@@ -1,11 +1,11 @@
 //! Limb encoding
 
-use super::{Inner, Limb};
+use super::{Limb, LimbUInt};
 use crate::Encoding;
 
 impl Encoding for Limb {
-    const BIT_SIZE: usize = super::BIT_SIZE;
-    const BYTE_SIZE: usize = super::BYTE_SIZE;
+    const BIT_SIZE: usize = Self::BIT_SIZE;
+    const BYTE_SIZE: usize = Self::BYTE_SIZE;
 
     #[cfg(target_pointer_width = "32")]
     type Repr = [u8; 4];
@@ -14,12 +14,12 @@ impl Encoding for Limb {
 
     #[inline]
     fn from_be_bytes(bytes: Self::Repr) -> Self {
-        Limb(Inner::from_be_bytes(bytes))
+        Limb(LimbUInt::from_be_bytes(bytes))
     }
 
     #[inline]
     fn from_le_bytes(bytes: Self::Repr) -> Self {
-        Limb(Inner::from_le_bytes(bytes))
+        Limb(LimbUInt::from_le_bytes(bytes))
     }
 
     #[inline]
